@@ -5,7 +5,7 @@ package MooX::AttributeFilter;
 use v5.10;
 use strictures 1;
 
-our $VERSION = '0.002902'; # TRIAL
+our $VERSION = '0.002903'; # TRIAL
 
 use Carp;
 use Scalar::Util qw<looks_like_number>;
@@ -124,8 +124,8 @@ install_modifier "Method::Generate::Accessor", 'around', 'generate_method',
 
     if ( $filterClasses{$into} && $spec->{filter} ) {
 
-        croak "Incompatibe 'is' option '$spec->{is}': can't install filter"
-          unless $spec->{is} =~ /^rwp?$/;
+        #croak "Incompatibe 'is' option '$spec->{is}': can't install filter"
+        #  unless $spec->{is} =~ /^(rwp?|ro)$/;
 
         my $filterSub;
         if ( $spec->{filter} eq 1 ) {
@@ -194,7 +194,7 @@ MooX::AttributeFilter - Implements 'filter' option for Moo-class attributes
 
 =head1 VERSION
 
-version 0.002902
+version 0.002903
 
 =head1 SYNOPSIS
 
